Theory & Belief Revision
========================

AGM belief revision engine, provenance DAG, failure analysis, and rollback.

.. automodule:: theory.manager
   :members:
   :show-inheritance:

.. automodule:: theory.assertions
   :members:
   :show-inheritance:

.. automodule:: theory.provenance
   :members:
   :show-inheritance:

.. automodule:: theory.failure_analyzer
   :members:
   :show-inheritance:

.. automodule:: theory.rollback
   :members:
   :show-inheritance:
